==> plugin-android-0.0.1-sources.jar: com/zoyi/channel/plugin/android/model/rest/File.java <==
package com.zoyi.channel.plugin.android.model.rest;

/**
 * Created by mika on 2016. 1. 22..
 */
public class File implements ChannelModel {
  private String id;
  private String channelId;
  private String chatType;
  private String chatId;
  private String name;
  private String filename;
  private Long size;
  private String type;
  private String state;
  private String personType;
  private String personId;
  private Long createdAt;
  private String url;
  private boolean image;
  private PreviewThumb previewThumb;
  private String extension;

  public String getId() {
    return id;
  }

  public void setId(String id) {
    this.id = id;
  }

  public String getChannelId() {
    return channelId;
  }

  public void setChannelId(String channelId) {
    this.channelId = channelId;
  }

  public String getChatType() {
    return chatType;
  }

  public void setChatType(String chatType) {
    this.chatType = chatType;
  }

  public String getChatId() {
    return chatId;
  }

  public void setChatId(String chatId) {
    this.chatId = chatId;
  }

  public String getName() {
    return name;
  }

  public void setName(String name) {
    this.name = name;
  }

  public String getFilename() {
    return filename;
  }

  public void setFilename(String filename) {
    this.filename = filename;
  }

  public Long getSize() {
    return size;
  }

  public void setSize(Long size) {
    this.size = size;
  }

  public String getType() {
    return type;
  }

  public void setType(String type) {
    this.type = type;
  }

  public String getState() {
    return state;
  }

  public void setState(String state) {
    this.state = state;
  }

  public String getPersonType() {
    return personType;
  }

  public void setPersonType(String personType) {
    this.personType = personType;
  }

  public String getPersonId() {
    return personId;
  }

  public void setPersonId(String personId) {
    this.personId = personId;
  }

  public Long getCreatedAt() {
    return createdAt;
  }

  public void setCreatedAt(Long createdAt) {
    this.createdAt = createdAt;
  }

  public String getUrl() {
    return url;
  }

  public void setUrl(String url) {
    this.url = url;
  }

  public boolean isImage() {
    return image;
  }

  public void setImage(boolean image) {
    this.image = image;
  }

  public PreviewThumb getPreviewThumb() {
    return previewThumb;
  }

  public String getExtension() {
    return extension;
  }

  public final static String CLASSNAME = "File";
}

==> plugin-android-3.0.0-sources.jar: com/zoyi/channel/plugin/android/model/rest/File.java <==
package com.zoyi.channel.plugin.android.model.rest;

import com.zoyi.channel.plugin.android.model.interfaces.ChannelModel;

/**
 * Created by mika on 2016. 1. 22..
 */
public class File implements ChannelModel {
  private String id;
  private String channelId;
  private String chatType;
  private String chatId;
  private String name;
  private String filename;
  private Long size;
  private String type;
  private String state;
  private String personType;
  private String personId;
  private String url;
  private boolean image;
  private PreviewThumb previewThumb;
  private String extension;

  public File() {}

  public File(String id) {
    this.id = id;
  }

  @Override
  public boolean equals(Object obj) {
    boolean ret = false;

    if (obj != null && obj instanceof File) {
      File next = (File) obj;

      ret = this.id.equals(next.id);
    }
    return ret;
  }

  public String getId() {
    return id;
  }

  public void setId(String id) {
    this.id = id;
  }

  public String getChannelId() {
    return channelId;
  }

  public void setChannelId(String channelId) {
    this.channelId = channelId;
  }

  public String getChatType() {
    return chatType;
  }

  public void setChatType(String chatType) {
    this.chatType = chatType;
  }

  public String getChatId() {
    return chatId;
  }

  public void setChatId(String chatId) {
    this.chatId = chatId;
  }

  public String getName() {
    return name;
  }

  public void setName(String name) {
    this.name = name;
  }

  public String getFilename() {
    return filename;
  }

  public void setFilename(String filename) {
    this.filename = filename;
  }

  public Long getSize() {
    return size;
  }

  public void setSize(Long size) {
    this.size = size;
  }

  public String getType() {
    return type;
  }

  public void setType(String type) {
    this.type = type;
  }

  public String getState() {
    return state;
  }

  public void setState(String state) {
    this.state = state;
  }

  public String getPersonType() {
    return personType;
  }

  public void setPersonType(String personType) {
    this.personType = personType;
  }

  public String getPersonId() {
    return personId;
  }

  public void setPersonId(String personId) {
    this.personId = personId;
  }

  public String getUrl() {
    return url;
  }

  public void setUrl(String url) {
    this.url = url;
  }

  public boolean isImage() {
    return image;
  }

  public void setImage(boolean image) {
    this.image = image;
  }

  public PreviewThumb getPreviewThumb() {
    return previewThumb;
  }

  public String getExtension() {
    return extension;
  }

  public final static String CLASSNAME = "File";
}
